from django.shortcuts import render, redirect
from django.views import View
from django.contrib import messages
from django.conf import settings
from django.apps import apps
from .middleware import LRNDMiddleware

class ValidateView(View):
    template_name = 'djangoLrnd/validate.html'

    def get(self, request):
        return render(request, self.template_name)

    def post(self, request):
        key = request.POST.get('key')
        if not key:
            messages.error(request, 'Please provide a key.')
            return render(request, self.template_name)

        response = LRNDMiddleware.check_key_status(key)
        if response.status_code == 200:
            LRNDKey = apps.get_model('djangoLrnd', 'LRNDKey')
            LRNDKey.objects.update_or_create(id=1, defaults={'key': key})
            messages.success(request, 'Key validated successfully.')
            success_redirect_url = getattr(settings, 'LRND_SUCCESS_REDIRECT_URL', 'home')
            return redirect(success_redirect_url)
        else:
            messages.error(request, 'Invalid key. Please try again.')
            return render(request, self.template_name)

validate_view = ValidateView.as_view()


from setuptools import setup, find_packages

setup(
    name='djangoLrnd',
    version='0.6',
    packages=find_packages(),
    include_package_data=True,
    license='MIT',
    description='A Django middleware for LRND validation.',
    author='Lrnd',
    author_email='hafiztamvan15@gmail.com',
    classifiers=[
        'Environment :: Web Environment',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Topic :: Internet :: WWW/HTTP',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
    ],
    install_requires=[
        'django',
        'requests',
        'cryptography',
    ],
)